<?php
/*
  Plugin Name: EngageBay Gravity Forms Addon
  Plugin URI: https://www.engagebay.com/new-gravity-forms
  Description: EngageBay Gravity Forms integration plugin for gravity forms. Sync form entries to my website easily.
  Version: 3.1.3
  Requires at least: 4.0
  Tested up to: 6.6.2
  Author: EngageBay
  Author URI: https://www.engagebay.com
 */

defined('ABSPATH') or die('Plugin file cannot be accessed directly.');

$activated_plugins = apply_filters('active_plugins', get_option('active_plugins'));

if (!in_array('gravityforms/gravityforms.php', $activated_plugins, true)) {
    wp_admin_notice('EngageBay Gravity Forms Activation Error: Install / Activate Gravity Forms plugin');
    return;
}

if (class_exists('GFForms') && !class_exists('EngageBayGFAddon')) {
    GFForms::include_addon_framework();

    class EngageBayGFAddon extends GFAddOn
    {
        protected $_version = '3.1.2';
        protected $_min_gravityforms_version = '1.8.7';
        protected $_slug = 'engagebay';
        protected $_path = 'engagebaygfaddon/engagebaygfaddon.php';
        protected $_full_path = __FILE__;
        protected $_title = 'EngageBay Gravity Forms';
        protected $_short_title = 'EngageBay';

        public function __construct()
        {
            parent::__construct();

            $this->eb_gf_setup_dependencies();

            add_action('upgrader_process_complete', array($this, 'eb_gf_upgrade_hook'), 10, 2);
        }

        private function eb_gf_setup_dependencies()
        {
            require_once('includes/engagebay-gf-addon-vars.php');
            require_once('includes/engagebay-gf-addon-activation-handler.php');
            require_once('includes/engagebay-gf-addon-api.php');
            require_once('includes/engagebay-gf-addon-form-handler.php');
        }

        public function init_frontend()
        {
            parent::init_frontend();
            $form_handler = new EngageBayGFAddonFormHandler();
            $form_handler->eb_gf_add_actions();

            add_action( 'wp_enqueue_scripts', array( $this, 'eb_gf_enqueue_scripts' ), 2 );
        }

        public function eb_gf_enqueue_scripts()
        {
            wp_enqueue_script('engagebay_script', plugins_url('/js/engagebay.js', __FILE__));

            $engageBayDomain = get_option('engagebay_domain', false);
            if (!$engageBayDomain) {
                $engageBayDomain = $this->eb_gf_fetch_engagebay_domain();
                if (!$engageBayDomain) {
                    $this->log_error('Couldn\'t fetch EngageBay Domain');
                    return;
                }
            }

            $data = array(
                'engagebay_domain' => $engageBayDomain,
                'engagebay_js_api_key' => $this->get_plugin_setting('engagebay_js_api_key'),
                'engagebay_web_popups' => $this->get_plugin_setting('engagebay_web_popups'),
            );

            wp_localize_script('engagebay_script', 'settings', $data);
        }

        public function plugin_settings_icon()
        {
            return "<img style='height:25px' src='" . plugins_url('/images/engagebay_logo.png', __FILE__) . "'  title='Engage Bay logo' class='logo'/>";
        }

        public function plugin_settings_fields()
        {
            return array(
                array(
                    'title' => __('EngageBay Gravity Forms Add-on Settings'),
                    'description' => $this->eb_gf_plugin_settings_description(),
                    'fields' => array(
                        array(
                            'name' => 'engagebay_rest_api_key',
                            'tooltip' => __('Get your REST API key from the API section under the Account Settings option.', 'engagebaygfaddon'),
                            'label' => __('REST API Key', 'engagebaygfaddon'),
                            'type' => 'text',
                            'class' => 'medium',
                            'validation_callback' => array($this, 'eb_gf_validate_rest_api'),
                            'placeholder' => 'Enter the Rest API key',
                        ),
                        array(
                            'name' => 'engagebay_web_popups',
                            'type' => 'checkbox',
                            'choices' => array(
                                array(
                                    'label' => __('Show Web Popups', 'engagebaygfaddon'),
                                    'name' => 'engagebay_web_popups',
                                    'default_value' => 1,
                                ),
                            ),
                        ),
                    ),
                ),
            );
        }

        public function form_settings_fields($form)
        {
            $form_handler = new EngageBayGFAddonFormHandler();
            return $form_handler->eb_gf_settings($form);
        }

        public function update_plugin_settings($settings)
        {
            $api_handler = new EngagebayGFAddonAPI();
            $settings['engagebay_js_api_key'] = $api_handler->get_js_api_key($settings['engagebay_rest_api_key']);

            parent::update_plugin_settings($settings);
        }

        private function eb_gf_fetch_engagebay_domain()
        {
            $rest_api_key = $this->get_plugin_setting('engagebay_rest_api_key');

            if (!$rest_api_key) {
                $this->log_error("EngageBay Rest API Key not found");
                return null;
            }

            $api_handler = new EngagebayGFAddonAPI();
            $result = $api_handler->get_domain_info();

            if (isset($result['name'])) {
                add_option('engagebay_domain', $result['name']);
                return $result['name'];
            }

            return null;
        }

        public function eb_gf_plugin_settings_description()
        {
            $description = '<p>';
            $description .= sprintf(
                esc_html__('Integrate Gravity Forms with EngageBay to seamlessly collect customer information from submitted forms. Don’t have an EngageBay account? %1$sRegister here.%2$s', 'engagebaygfaddon'),
                '<a href="https://app.engagebay.com/signup" target="_blank">', '</a>'
            );
            $description .= '</p>';
            return $description;
        }

        public function eb_gf_validate_rest_api($field, $value)
        {
            $engageBay_api = new EngagebayGFAddonAPI();
            if (!$engageBay_api->is_valid_rest_api_key($value)) {
                $field->set_error("Invalid REST API Key");
            }
        }

        public static function eb_gf_rest_api_key()
        {
            $self = new self();
            return $self->get_plugin_setting('engagebay_rest_api_key');
        }

        public static function eb_gf_form_settings($form)
        {
            $self = new self();
            return $self->get_form_settings($form);
        }

        public function eb_gf_upgrade_hook($upgrader_object, $options) {
            $current_plugin_path_name = plugin_basename( __FILE__ );

            if ($options['action'] == 'update' && $options['type'] == 'plugin' && isset( $options['plugins'])) {
                foreach($options['plugins'] as $plugin) {
                    if ($plugin == $current_plugin_path_name) {
                        if (get_option('gravityformsaddon_engagebay_version')) {
                            update_option('gravityformsaddon_engagebay_version', $this->get_version());
                        }

                        $api_handler = new EngagebayGFAddonAPI();
                        $api_handler->send_ecommerce_hook();
                    }
                }
            }
        }
    }
}

if (!class_exists('EngageBayGFAddon')) {
    class EngageBayGFAddon {}
}

new EngageBayGFAddon();
